==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/pages/app/EditAppBody.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/pages/app/EditAppBody.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../../components/management-toolbar/search/SearchInput.es', '../../hooks/index.es', './ListItems.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _SearchInput = _interopRequireDefault(require("../../components/management-toolbar/search/SearchInput.es"));

  var _index = require("../../hooks/index.es");

  var _ListItems = _interopRequireDefault(require("./ListItems.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  function _extends() {
    _extends = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }return target;
    };return _extends.apply(this, arguments);
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};var target = _objectWithoutPropertiesLoose(source, excluded);var key, i;if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];if (excluded.indexOf(key) >= 0) continue;if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;target[key] = source[key];
      }
    }return target;
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};var target = {};var sourceKeys = Object.keys(source);var key, i;for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];if (excluded.indexOf(key) >= 0) continue;target[key] = source[key];
    }return target;
  }

  var _default = function _default(_ref) {
    var endpoint = _ref.endpoint,
        title = _ref.title,
        restProps = _objectWithoutProperties(_ref, ["endpoint", "title"]);

    var _useState = (0, _react.useState)(''),
        _useState2 = _slicedToArray(_useState, 2),
        searchText = _useState2[0],
        setSearchText = _useState2[1];

    var _useRequest = (0, _index.useRequest)(endpoint),
        _useRequest$response$ = _useRequest.response.items,
        items = _useRequest$response$ === void 0 ? [] : _useRequest$response$,
        isLoading = _useRequest.isLoading;

    var filteredItems = items.filter(function (item) {
      return new RegExp(searchText, 'ig').test(item.name.en_US);
    });
    return _react["default"].createElement(_react["default"].Fragment, null, _react["default"].createElement("div", {
      className: "autofit-row mb-4 pl-4 pr-4"
    }, _react["default"].createElement("div", {
      className: "autofit-col-expand"
    }, _react["default"].createElement("h2", null, title))), _react["default"].createElement("div", {
      className: "autofit-row mb-4 pl-4 pr-4"
    }, _react["default"].createElement("div", {
      className: "autofit-col-expand"
    }, _react["default"].createElement(_SearchInput["default"], {
      onChange: function onChange(searchText) {
        return setSearchText(searchText);
      }
    }))), _react["default"].createElement("div", {
      className: "autofit-row pl-4 pr-4 scrollable-container"
    }, _react["default"].createElement("div", {
      className: "autofit-col-expand"
    }, _react["default"].createElement(_ListItems["default"], _extends({
      isEmpty: filteredItems.length === 0,
      isLoading: isLoading,
      items: filteredItems,
      keywords: searchText
    }, restProps)))));
  };

  exports["default"] = _default;
  //# sourceMappingURL=EditAppBody.es.js.map
});
//# sourceMappingURL=EditAppBody.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/pages/app/EditAppBody.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/pages/app/EditAppBody.es", ['module', 'exports', 'require', 'data-engine-taglib', 'frontend-js-react-web$react', '../../hooks/index.es', './ListItems.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _dataEngineTaglib = require("data-engine-taglib");

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _index = require("../../hooks/index.es");

  var _ListItems = _interopRequireDefault(require("./ListItems.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _extends() {
    _extends = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }return target;
    };return _extends.apply(this, arguments);
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};var target = _objectWithoutPropertiesLoose(source, excluded);var key, i;if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];if (excluded.indexOf(key) >= 0) continue;if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;target[key] = source[key];
      }
    }return target;
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};var target = {};var sourceKeys = Object.keys(source);var key, i;for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];if (excluded.indexOf(key) >= 0) continue;target[key] = source[key];
    }return target;
  }

  var _default = function _default(_ref) {
    var endpoint = _ref.endpoint,
        title = _ref.title,
        restProps = _objectWithoutProperties(_ref, ["endpoint", "title"]);

    var _useState = (0, _react.useState)(''),
        _useState2 = _slicedToArray(_useState, 2),
        searchText = _useState2[0],
        setSearchText = _useState2[1];

    var _useRequest = (0, _index.useRequest)(endpoint),
        _useRequest$response$ = _useRequest.response.items,
        items = _useRequest$response$ === void 0 ? [] : _useRequest$response$,
        isLoading = _useRequest.isLoading;

    var filteredItems = items.filter(function (item) {
      return new RegExp(searchText, 'ig').test(item.name.en_US);
    });
    return _react["default"].createElement(_react["default"].Fragment, null, _react["default"].createElement("div", {
      className: "autofit-row mb-4 pl-4 pr-4"
    }, _react["default"].createElement("div", {
      className: "autofit-col-expand"
    }, _react["default"].createElement("h2", null, title))), _react["default"].createElement("div", {
      className: "autofit-row mb-4 pl-4 pr-4"
    }, _react["default"].createElement("div", {
      className: "autofit-col-expand"
    }, _react["default"].createElement(_dataEngineTaglib.SearchInput, {
      onChange: function onChange(searchText) {
        return setSearchText(searchText);
      }
    }))), _react["default"].createElement("div", {
      className: "autofit-row pl-4 pr-4 scrollable-container"
    }, _react["default"].createElement("div", {
      className: "autofit-col-expand"
    }, _react["default"].createElement(_ListItems["default"], _extends({
      isEmpty: filteredItems.length === 0,
      isLoading: isLoading,
      items: filteredItems,
      keywords: searchText
    }, restProps)))));
  };

  exports["default"] = _default;
  //# sourceMappingURL=EditAppBody.es.js.map
});
//# sourceMappingURL=EditAppBody.es.js.map
